from auth0.v3.authentication import GetToken
import os


def get_access_token(service: str):
    '''Get access token'''
    auth0_domain = os.environ["AUTH_DOMAIN"]
    non_interactive_client_id = os.environ["AUTH_CLIENT_ID"]
    non_interactive_client_secret = os.environ["AUTH_CLIENT_SECRET"]
    get_token = GetToken(auth0_domain)
    return get_token.client_credentials(non_interactive_client_id,
                                        non_interactive_client_secret, service)



# coding: utf-8

# flake8: noqa
"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from kaistack.clients.openapi_clients.models.codegen_argo_workflow import CodegenArgoWorkflow
from kaistack.clients.openapi_clients.models.codegen_artifact import CodegenArtifact
from kaistack.clients.openapi_clients.models.codegen_artifact_meta import CodegenArtifactMeta
from kaistack.clients.openapi_clients.models.codegen_create_run_response import CodegenCreateRunResponse
from kaistack.clients.openapi_clients.models.codegen_get_argo_workflow_response import CodegenGetArgoWorkflowResponse
from kaistack.clients.openapi_clients.models.codegen_get_artifact_with_properties_response import CodegenGetArtifactWithPropertiesResponse
from kaistack.clients.openapi_clients.models.codegen_get_artifacts_filter import CodegenGetArtifactsFilter
from kaistack.clients.openapi_clients.models.codegen_get_artifacts_response import CodegenGetArtifactsResponse
from kaistack.clients.openapi_clients.models.codegen_get_metrics_response import CodegenGetMetricsResponse
from kaistack.clients.openapi_clients.models.codegen_get_params_response import CodegenGetParamsResponse
from kaistack.clients.openapi_clients.models.codegen_get_pipeline_experiment_name_response import CodegenGetPipelineExperimentNameResponse
from kaistack.clients.openapi_clients.models.codegen_get_pipeline_run_id_response import CodegenGetPipelineRunIdResponse
from kaistack.clients.openapi_clients.models.codegen_get_pipeline_runs_response import CodegenGetPipelineRunsResponse
from kaistack.clients.openapi_clients.models.codegen_get_run_by_name_response import CodegenGetRunByNameResponse
from kaistack.clients.openapi_clients.models.codegen_get_run_response import CodegenGetRunResponse
from kaistack.clients.openapi_clients.models.codegen_log_artifact_meta_response import CodegenLogArtifactMetaResponse
from kaistack.clients.openapi_clients.models.codegen_log_metrics_response import CodegenLogMetricsResponse
from kaistack.clients.openapi_clients.models.codegen_log_params_response import CodegenLogParamsResponse
from kaistack.clients.openapi_clients.models.codegen_metric import CodegenMetric
from kaistack.clients.openapi_clients.models.codegen_param import CodegenParam
from kaistack.clients.openapi_clients.models.codegen_run import CodegenRun



# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.models.codegen_get_cluster_config_response import CodegenGetClusterConfigResponse  # noqa: E501
from kaistack.clients.openapi_clients.cluster.rest import ApiException

class TestCodegenGetClusterConfigResponse(unittest.TestCase):
    """CodegenGetClusterConfigResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetClusterConfigResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.cluster.models.codegen_get_cluster_config_response.CodegenGetClusterConfigResponse()  # noqa: E501
        if include_optional :
            return CodegenGetClusterConfigResponse(
                config = kaistack.clients.openapi_clients.cluster.models.codegen_cluster_config.codegenClusterConfig(
                    artifacts_store = kaistack.clients.openapi_clients.cluster.models.codegen_artifacts_store_config.codegenArtifactsStoreConfig(
                        bucket = '0', 
                        key_prefix = '0', ), )
            )
        else :
            return CodegenGetClusterConfigResponse(
        )

    def testCodegenGetClusterConfigResponse(self):
        """Test CodegenGetClusterConfigResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import argparse
import kaistack
import logging
import yaml
from kaistack.components.component_store import ComponentStore
from kaistack.components.kubeflow_converter import create_workflow_template_from_component_spec

logger = logging.getLogger("Component Importer")

def convert_component(path):
    wf = create_workflow_template_from_component_spec(path)
    return wf


def import_component(args):
    spec = ''
    if not args.convert:
        # Sniff the file
        with open(args.path, 'r') as f:
            spec = f.read()
            args.convert = not spec.startswith("apiVersion")
    if args.convert:
        logger.info("Convert the spec")
        spec = convert_component(args.path)

    if not args.apibase:
        args.apibase = args.service
    logger.info("Initialize component store. service:[%s] api_base [%s]", args.service, args.apibase)
    store = ComponentStore(args.service, args.apibase)
    try:
        store.create_component(yaml.dump(spec), args.name)
        logger.info("Create component successfully")
    except kaistack.clients.openapi_clients.pipelinecomponents.exceptions.ApiException:
        store.update_component(yaml.dump(spec), args.name)
        logger.info("Update component successfully")


def main():
    parser = argparse.ArgumentParser(description='Import a kubeflow component')
    parser.add_argument('--path', required=True, help='The input file path')
    parser.add_argument('--service', help='The service name')
    parser.add_argument('--apibase', help='The api endpoint base. Only set if it is different from the service')
    parser.add_argument('--name', help="The component name. If not set, it will by default use the name in the yaml")
    parser.add_argument('--convert', action="store_true",
                        help='If configured, will convert from kfp component spec. If not set, the progam will detect')

    console_handler = logging.StreamHandler()
    logger.addHandler(console_handler)
    logger.setLevel(logging.INFO)
    args = parser.parse_args()
    import_component(args)


if __name__ == '__main__':
    main()
